@@ -1,4 +1,4 @@
-use v6.c;
+use v6;
 
 =begin pod
 
@@ -85,7 +85,7 @@ audio is detected to end.
 
 =end pod
 
-class Audio::Silan:ver<0.0.3>:auth<github:jonathanstowe> {
+class Audio::Silan:ver<0.0.5>:auth<github:jonathanstowe>:api<1.0> {
     use File::Which;
     use JSON::Fast;
 
